#!/bin/sh
# Name: CCcam_2.1.3-mpcs_1.06_pr3-script_091116.tar.gz
# Version: 2.1.3
# Type: Cam

kill `pidof mpcs_1.06_pr3 `
killall -9 mpcs_1.06_pr3 CCcam_2.1.3 2>/dev/null
sleep 2
remove_tmp

rm -rf /var/script/CCcam_2.1.3_mpcs_1.06_pr3_cam.sh
rm -rf /var/uninstall/CCcam_2.1.3-mpcs_1.06_pr3-script_delfile.sh

exit 0

######################################
####### Powered by Gemini Team #######
## http://www.i-have-a-dreambox.com ##
######################################
