#!/bin/sh
# Name: CCcam_2.1.3-newcs_1.67-script_091116.tar.gz
# Version: 2.1.3
# Type: Cam

kill `pidof newcs_1.67 `
killall -9 newcs_1.67 CCcam_2.1.3 2>/dev/null
sleep 2
remove_tmp

rm -rf /var/script/CCcam_2.1.3_newcs_1.67_cam.sh
rm -rf /var/uninstall/CCcam_2.1.3-newcs_1.67-script_delfile.sh

exit 0

######################################
####### Powered by Gemini Team #######
## http://www.i-have-a-dreambox.com ##
######################################
